@@ -13,6 +13,7 @@
 #![deny(rustdoc::broken_intra_doc_links)]
 #![allow(clippy::upper_case_acronyms)]
 #![allow(renamed_and_removed_lints)]
+#![allow(unknown_lints)]
 
 #[cfg(feature = "debug")]
 #[doc(hidden)]
@@ -62,9 +63,10 @@ cfg_if::cfg_if! {
 }
 
 pub use common::{
-    AsU32, DiskType, DiskUsage, Gid, LoadAvg, NetworksIter, Pid, RefreshKind, Signal, Uid, User,
+    AsU32, DiskType, DiskUsage, Gid, LoadAvg, NetworksIter, Pid, ProcessStatus, RefreshKind,
+    Signal, Uid, User,
 };
-pub use sys::{Component, Disk, NetworkData, Networks, Process, ProcessStatus, Processor, System};
+pub use sys::{Component, Disk, NetworkData, Networks, Process, Processor, System};
 pub use traits::{
     ComponentExt, DiskExt, NetworkExt, NetworksExt, ProcessExt, ProcessorExt, SystemExt, UserExt,
 };
@@ -316,6 +318,7 @@ mod test {
             assert!(s.processors().is_empty());
             assert_eq!(s.physical_core_count(), None);
         }
+        assert!(s.physical_core_count().unwrap_or(0) <= s.processors().len());
     }
 }
 
