@@ -232,7 +232,7 @@ impl Query {
     }
 }
 
-/// Struct containing a processor information.
+#[doc = include_str!("../../md_doc/processor.md")]
 pub struct Processor {
     name: String,
     cpu_usage: f32,
