@@ -45,7 +45,7 @@ use winapi::um::sysinfoapi::{
 use winapi::um::winnt::{HANDLE, KEY_READ};
 use winapi::um::winreg::{RegOpenKeyExW, RegQueryValueExW};
 
-/// Struct containing the system's information.
+#[doc = include_str!("../../md_doc/system.md")]
 pub struct System {
     process_list: HashMap<usize, Process>,
     mem_total: u64,
@@ -65,6 +65,7 @@ pub struct System {
 // Useful for parallel iterations.
 struct Wrap<T>(T);
 
+#[allow(clippy::non_send_fields_in_send_ty)]
 unsafe impl<T> Send for Wrap<T> {}
 unsafe impl<T> Sync for Wrap<T> {}
 
